# -*- coding: utf-8 -*-
# Copyright (c) 2014-2023, Philip Xu <pyx@xrefactor.com>
# License: BSD New, see LICENSE for details.
"""Hy Monad Notation - a monad library for Hy"""

__version__ = "1.1.0"

# make .hy file importable
import hy  # noqa
